import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "p6-namer", "0.7.182", __name__[0:-6], "p6-namer@0.7.182.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
